@@ -1079,7 +1079,7 @@ def do_backup_update(cs, args):
            help='Cluster binary. Default=None.')
 @utils.arg('--is-up', metavar='<True|true|False|false>', default=None,
            choices=('True', 'true', 'False', 'false'),
-           help='Filter by up/dow status. Default=None.')
+           help='Filter by up/down status. Default=None.')
 @utils.arg('--disabled', metavar='<True|true|False|false>', default=None,
            choices=('True', 'true', 'False', 'false'),
            help='Filter by disabled status. Default=None.')
@@ -2410,6 +2410,7 @@ def do_version_list(cs, args):
            default='',
            help='Prefix for the log. ie: "cinder.volume.drivers.".')
 def do_service_set_log(cs, args):
+    """Sets the service log level."""
     cs.services.set_log_levels(args.level, args.binary, args.server,
                                args.prefix)
 
@@ -2427,6 +2428,7 @@ def do_service_set_log(cs, args):
            default='',
            help='Prefix for the log. ie: "sqlalchemy.".')
 def do_service_get_log(cs, args):
+    """Gets the service log level."""
     log_levels = cs.services.get_log_levels(args.binary, args.server,
                                             args.prefix)
     columns = ('Binary', 'Host', 'Prefix', 'Level')
@@ -2569,12 +2571,22 @@ def do_transfer_create(cs, args):
            default=None,
            help='Sort keys and directions in the form of <key>[:<asc|desc>].',
            start_version='3.59')
+@utils.arg('--filters',
+           action=AppendFilters,
+           type=six.text_type,
+           nargs='*',
+           start_version='3.52',
+           metavar='<key=value>',
+           default=None,
+           help="Filter key and value pairs.")
 def do_transfer_list(cs, args):
     """Lists all transfers."""
     all_tenants = int(os.environ.get("ALL_TENANTS", args.all_tenants))
     search_opts = {
         'all_tenants': all_tenants,
     }
+    if AppendFilters.filters:
+        search_opts.update(shell_utils.extract_filters(AppendFilters.filters))
 
     sort = getattr(args, 'sort', None)
     if sort:
@@ -2587,3 +2599,4 @@ def do_transfer_list(cs, args):
     transfers = cs.transfers.list(search_opts=search_opts, sort=sort)
     columns = ['ID', 'Volume ID', 'Name']
     utils.print_list(transfers, columns)
+    AppendFilters.filters = []
